==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>正在檢查，即將完成，感謝您耐心等待</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>正在準備</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>檢查到一些錯誤</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>進入桌面</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>歡迎您，系統已成功升級</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>目前版本：</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>查看日誌</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>更新成功</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>您的電腦即將重啟 %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>您的電腦即將關機 %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>未能自動完成重啟操作，請嘗試手動重啟您的裝置。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>未能自動完成關機操作，請嘗試手動關閉您的裝置。</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>收起日誌</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>更新失敗</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知錯誤</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>備份失敗</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系統無法備份，繼續升級，系統將無法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>磁碟空間不足，請清理磁碟後再更新</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>無法啟動備份服務，請檢查後重試</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>無法啟動更新服務，請檢查後重試</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依賴錯誤</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg錯誤</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>重新備份</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>退出更新</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>繼續更新</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重啟</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>進入桌面</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>正在準備更新...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>更新時請勿強制關機或斷電，否則會導致系統損壞</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-update/translations/dde-update_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>正在檢查，即將完成，感謝您耐心等待</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>正在準備</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>檢查到一些錯誤</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>進入桌面</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>歡迎您，系統已成功升級</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>目前版本：</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>更新成功</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>您的電腦即將重啟 %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>您的電腦即將關機 %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>未能自動完成重啟操作，請嘗試手動重啟您的裝置。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>未能自動完成關機操作，請嘗試手動關閉您的裝置。</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>檢視更新日誌</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>收起更新日誌</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>匯出</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>日誌已匯出至桌面</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>日誌匯出失敗, 請重試嘗試</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>更新失敗</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知錯誤</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>備份失敗</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>系統無法備份，繼續升級，系統將無法回退</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>磁碟空間不足，請清理磁碟後再更新</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>無法啟動備份服務，請檢查後重試</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>無法啟動更新服務，請檢查後重試</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依賴錯誤</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>dpkg錯誤</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>重新備份</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>退出更新</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>繼續更新</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重啟</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>進入桌面</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>正在準備更新...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>更新時請勿強制關機或斷電，否則會導致系統損壞</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>檢視更新日誌</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>收起更新日誌</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>更新日誌</translation>
    </message>
</context>
</TS>
